#
# spec file for package libidl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name libIDL
Name:           libidl
Version:        0.8.14
Release:        24.3
# NOTE: on upgrade to a new upstream version, change the Obsoletes from <= to <
Summary:        IDL Parsing Library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            http://www.gnome.org
Source:         http://ftp.gnome.org/pub/GNOME/sources/%{_name}/0.8/%{_name}-%{version}.tar.bz2
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  glib2-devel
BuildRequires:  pkgconfig

%description
LibIDL is a small library for creating parse trees of CORBA
v2.2-compliant Interface Definition Language (IDL) files. IDL is a
specification for defining interfaces that can be used between
different CORBA implementations.

%package -n libIDL-2-0
Summary:        IDL Parsing Library
Group:          System/Libraries
Provides:       %{name} = %{version}
# Note: we keep <= (and a rpmlint warning...) until we get a version higher than 0.8.14 (when this provides/obsoletes was introduced)
Obsoletes:      %{name} <= %{version}
#

%description -n libIDL-2-0
LibIDL is a small library for creating parse trees of CORBA
v2.2-compliant Interface Definition Language (IDL) files. IDL is a
specification for defining interfaces that can be used between
different CORBA implementations.

%package devel
Summary:        Development files for the IDL parsing library
Group:          Development/Languages/Other
Requires:       libIDL-2-0 = %{version}
Requires(post): %{install_info_prereq}
Requires(postun): %{install_info_prereq}
#

%description devel
LibIDL is a small library for creating parse trees of CORBA v2.2
compliant Interface Definition Language (IDL) files, which is a
specification for defining interfaces which can be used between
different CORBA implementations.

%prep
%setup -q -n %{_name}-%{version}

%build
%if 0%{?mageia}
aclocal
autoconf
%endif
%configure\
%if 0%{?mageia}
	--disable-dependency-tracking \
%endif
	--disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
mkdir -p %{buildroot}%{_datadir}
mkdir %{buildroot}%{_datadir}/idl
rm -f %{buildroot}%{_infodir}/dir

%post -n libIDL-2-0 -p /sbin/ldconfig
%postun -n libIDL-2-0 -p /sbin/ldconfig

%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/%{_name}2.info%{ext_info}

%postun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{_name}2.info%{ext_info}

%files -n libIDL-2-0
%license COPYING
%doc ChangeLog AUTHORS README* NEWS BUGS tstidl.c
%{_libdir}/libIDL-2.so.*
# generic directory for idl files
%dir %{_datadir}/idl

%files devel
%{_bindir}/%{_name}-config-2
%{_includedir}/*
%{_infodir}/%{_name}2.info%{ext_info}
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libIDL-2.so

%changelog
* Tue Mar  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: the -32bit packages are no longer needed and
  have not been part of Tumbleweed for a while already (build for
  i586 only enabled in LegacyX86).
* Mon Mar  5 2018 jengelh@inai.de
- Fix SRPM groups. Update summaries. Remove ineffective --with-pic.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Oct 18 2017 jayvdb@gmail.com
- Replace deprecated PreReq: with Requires(post): and Requires(postun):
- Explicitly remove %%{_infodir}/dir before creating package to
  allow builds on RHEL and derived Linux distributions
- Use %%{ext_info} to allow build on Mageia
- Enable configure option --disable-dependency-tracking to
  allow build on Mageia
* Mon Apr 15 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Mon Oct 11 2010 vuntz@opensuse.org
- Update packaging to use the shared library packaging policy:
  + Create libIDL-2-0 subpackage.
  + Add Provides/Obsoletes for libidl to libIDL-2-0.
  + Update baselibs.conf accordingly.
* Sun Apr 25 2010 meissner@suse.de
- add buildrequires pkg-config
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 0.8.14:
  + Fix build error in configure.in.
  + Remove CPP_STDINC cruft from configure.in.
  + Enable silent build rules.
* Thu Dec 17 2009 jengelh@medozas.de
- Add baselibs.conf as a source
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 0.8.13:
  + Clean up some warnings from sparse/gcc.
  + Makefile.am: Put local includes first.
- Remove AutoReqProv: it's default now.
- Remove indent BuildRequires.
- Remove autoreconf call.
- Use makeinstall
- Remove la files.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Dec 29 2008 mboman@suse.de
- Update to version 0.8.12:
  + Fix the build with bison 2.4
* Thu Aug 28 2008 maw@suse.de
- Update to version 1.8.11:
  + Bug fixed: bgo#474641.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Jan 29 2008 rodrigo@suse.de
- Update to version 0.8.10:
  * Fix the build with glib 2.15
  * Ignore "command-line" in addition to "command line" when handling
    output from cpp
* Fri Jan  4 2008 crrodriguez@suse.de
- remove unneded buildrequires on popt-devel (not used anymore)
- fix misplaced PreReq tag
* Mon Sep 17 2007 gekker@suse.de
- Update to version 0.8.9
  * Add missing braces (Dominique Quatravaux)
* Thu Mar 29 2007 meissner@suse.de
- buildrequires flex,bison
* Wed Mar 21 2007 maw@suse.de
- Update to version 0.8.8
- b.g.o bugs fixed, including 122032.
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Mon Dec 11 2006 sbrabec@suse.cz
- Spec file cleanup.
* Fri Dec  8 2006 maw@suse.de
- Move to /usr.
* Thu Aug 17 2006 jhargadon@suse.de
- update to version 0.8.7
- Clean up some dead code
- Fix compiler warning
- Don't use deprecated function g_basename()
- Handle IDLN_WIDE_CHAR, IDLN_WIDE_STRING and IDLN_SRCFILE
    in IDL_tree_free()/IDL_tree_free_real()
- Wind32 fixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 kukuk@suse.de
- Fix filelist
* Mon Aug  1 2005 gekker@suse.de
- Update to version 0.8.6
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Thu Feb 10 2005 gekker@suse.de
- Update version to 0.8.5
* Wed Nov 17 2004 gekker@suse.de
- Update version to 0.8.4
* Mon Mar 15 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Tue Mar  2 2004 sbrabec@suse.cz
- Fixed AC_DEFUN underquoting (bug #34763).
* Thu Feb  5 2004 hhetter@suse.de
- updated to version 0.8.3 [GNOME 2.4.2]
* Sun Jan 11 2004 adrian@suse.de
- add %%run_ldconfig
* Tue Jul 15 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Thu Jun 12 2003 sbrabec@suse.cz
- Updated to version 0.8.2.
* Sun Jun  1 2003 ro@suse.de
- fix info page installation
* Tue Jul  2 2002 hhetter@suse.de
- no longer require texinfo
* Tue Jun  4 2002 ro@suse.de
- fix requires for devel package
* Tue Jun  4 2002 hhetter@suse.de
- updated to 0.8.0 source frozen release
  * link against glib2
  * build fixes
* Wed May  8 2002 meissner@suse.de
- %%_lib changes
* Tue Apr  9 2002 hhetter@suse.de
- update to version 0.7.4 [gnome desktop beta3]
* Thu Jan 31 2002 hhetter@suse.de
- updated to version 0.7.3 [gnome desktop alpha2]
  * lexer.l: gcc 3.0 update
* Fri Jan 11 2002 hhetter@suse.de
- updated to version 0.7.2:
  * portability fixes
  * fix --version and --cflags output
  * build fixes
- specfile cleanup
* Wed Dec 12 2001 hhetter@suse.de
- added pkgconfig files to devel package
* Wed Dec 12 2001 hhetter@suse.de
- initial SuSE release for GNOME 2.0 platform
